@@ -16,10 +16,23 @@
         renderNoHealthAlertsMessage(page);
     }
 
+    function onConnectionHelpClick(e) {
+
+        e.preventDefault();
+        return false;
+    }
+
     window.DashboardPage = {
 
         newsStartIndex: 0,
 
+        onPageInit: function () {
+
+            var page = this;
+
+            page.querySelector('#btnConnectionHelp').addEventListener('click', onConnectionHelpClick);
+        },
+
         onPageShow: function () {
 
             var page = this;
@@ -151,7 +164,7 @@
                     var itemHtml = '';
 
                     itemHtml += '<a class="clearLink" href="' + item.Link + '" target="_blank">';
-                    itemHtml += '<div class="listItem">';
+                    itemHtml += '<div class="listItem listItem-noborder">';
 
                     itemHtml += '<i class="listItemIcon md-icon">dvr</i>';
 
@@ -309,7 +322,7 @@
 
                 var nowPlayingItem = session.NowPlayingItem;
 
-                var className = nowPlayingItem ? 'scalableCard card activeSession' : 'scalableCard card activeSession';
+                var className = nowPlayingItem ? 'scalableCard card activeSession backdropCard' : 'scalableCard card activeSession backdropCard';
 
                 if (session.TranscodingInfo && session.TranscodingInfo.CompletionPercentage) {
                     className += ' transcodingSession';
@@ -318,9 +331,9 @@
                 html += '<div class="' + className + '" id="' + rowId + '">';
 
                 html += '<div class="cardBox visualCardBox">';
-                html += '<div class="cardScalable">';
+                html += '<div class="cardScalable visualCardBox-cardScalable">';
 
-                html += '<div class="cardPadder"></div>';
+                html += '<div class="cardPadder cardPadder-backdrop"></div>';
                 html += '<div class="cardContent">';
 
                 html += '<div class="sessionNowPlayingContent"';
@@ -1026,7 +1039,7 @@
         }
     };
 
-    $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pagebeforehide', "#dashboardPage", DashboardPage.onPageHide);
+    $(document).on('pageinit', "#dashboardPage", DashboardPage.onPageInit).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pagebeforehide', "#dashboardPage", DashboardPage.onPageHide);
 
     (function ($, document, window) {
 
@@ -1034,7 +1047,7 @@
 
             var html = '';
 
-            html += '<div class="listItem">';
+            html += '<div class="listItem listItem-noborder">';
 
             var color = entry.Severity == 'Error' || entry.Severity == 'Fatal' || entry.Severity == 'Warn' ? '#cc0000' : '#52B54B';
 
