@@ -1,8 +1,8 @@
-﻿define(['viewManager', 'appSettings', 'appStorage', 'apphost', 'datetime', 'itemHelper', 'mediaInfo', 'scroller', 'indicators', 'dom', 'imageLoader', 'scrollStyles'], function (viewManager, appSettings, appStorage, appHost, datetime, itemHelper, mediaInfo, scroller, indicators, dom) {
+﻿define(['viewManager', 'appSettings', 'appStorage', 'apphost', 'datetime', 'itemHelper', 'mediaInfo', 'scroller', 'indicators', 'dom', 'browser', 'imageLoader', 'scrollStyles'], function (viewManager, appSettings, appStorage, appHost, datetime, itemHelper, mediaInfo, scroller, indicators, dom, browser) {
 
     function fadeInRight(elem) {
 
-        var pct = browserInfo.mobile ? '3.5%' : '0.5%';
+        var pct = browser.mobile ? '4%' : '0.5%';
 
         var keyframes = [
           { opacity: '0', transform: 'translate3d(' + pct + ', 0, 0)', offset: 0 },
@@ -15,28 +15,6 @@
         });
     }
 
-    function animateSelectionBar(button) {
-
-        var elem = button.querySelector('.pageTabButtonSelectionBar');
-
-        if (!elem) {
-            return;
-        }
-
-        var keyframes = [
-          { transform: 'translate3d(-100%, 0, 0)', offset: 0 },
-          { transform: 'none', offset: 1 }];
-
-        if (!elem.animate) {
-            return;
-        }
-        elem.animate(keyframes, {
-            duration: 120,
-            iterations: 1,
-            easing: 'ease-out'
-        });
-    }
-
     var libraryBrowser = (function (window, document, screen) {
 
         var pageSizeKey = 'pagesize_v4';
@@ -135,215 +113,88 @@
                 return true;
             },
 
-            selectedTab: function (tabs, selected) {
-
-                if (selected == null) {
-
-                    return tabs.selectedTabIndex || 0;
-                }
-
-                var current = LibraryBrowser.selectedTab(tabs);
-                tabs.selectedTabIndex = selected;
-                if (current == selected) {
-                    tabs.dispatchEvent(new CustomEvent("beforetabchange", {
-                        detail: {
-                            selectedTabIndex: selected
-                        }
-                    }));
-                    tabs.dispatchEvent(new CustomEvent("tabchange", {
-                        detail: {
-                            selectedTabIndex: selected
-                        }
-                    }));
-                } else {
-                    var tabButtons = tabs.querySelectorAll('.pageTabButton');
-                    tabButtons[selected].click();
-                }
-            },
-
             configureSwipeTabs: function (ownerpage, tabs) {
 
+                if (!browser.touch) {
+                    return;
+                }
+
                 var pageCount = ownerpage.querySelectorAll('.pageTabContent').length;
-
-                require(['hammer'], function (Hammer) {
-
-                    var hammertime = new Hammer(ownerpage);
-                    hammertime.get('swipe').set({ direction: Hammer.DIRECTION_HORIZONTAL });
-
-                    hammertime.on('swipeleft', function (e) {
-                        if (LibraryBrowser.allowSwipe(e.target)) {
-                            var selected = parseInt(LibraryBrowser.selectedTab(tabs) || '0');
-                            if (selected < (pageCount - 1)) {
-                                LibraryBrowser.selectedTab(tabs, selected + 1);
-                            }
+                var onSwipeLeft = function (e) {
+                    if (LibraryBrowser.allowSwipe(e.target) && ownerpage.contains(e.target)) {
+                        var selected = parseInt(tabs.selectedIndex() || '0');
+                        if (selected < (pageCount - 1)) {
+                            tabs.selectedIndex(selected + 1);
                         }
-                    });
+                    }
+                };
 
-                    hammertime.on('swiperight', function (e) {
-                        if (LibraryBrowser.allowSwipe(e.target)) {
-                            var selected = parseInt(LibraryBrowser.selectedTab(tabs) || '0');
-                            if (selected > 0) {
-                                LibraryBrowser.selectedTab(tabs, selected - 1);
-                            }
+                var onSwipeRight = function (e) {
+                    if (LibraryBrowser.allowSwipe(e.target) && ownerpage.contains(e.target)) {
+                        var selected = parseInt(tabs.selectedIndex() || '0');
+                        if (selected > 0) {
+                            tabs.selectedIndex(selected - 1);
                         }
+                    }
+                };
+
+                require(['hammer-main'], function (hammertime) {
+                    
+                    hammertime.on('swipeleft', onSwipeLeft);
+                    hammertime.on('swiperight', onSwipeRight);
+
+                    ownerpage.addEventListener('viewdestroy', function () {
+                        hammertime.off('swipeleft', onSwipeLeft);
+                        hammertime.off('swiperight', onSwipeRight);
                     });
                 });
             },
 
             configurePaperLibraryTabs: function (ownerpage, tabs, panels, animateTabs) {
 
-                if (!browserInfo.safari) {
+                if (!browser.safari) {
                     LibraryBrowser.configureSwipeTabs(ownerpage, tabs);
                 }
 
-                if (!browserInfo.safari || !AppInfo.isNativeApp) {
-                    var buttons = tabs.querySelectorAll('.pageTabButton');
-                    for (var i = 0, length = buttons.length; i < length; i++) {
-                        var div = document.createElement('div');
-                        div.classList.add('pageTabButtonSelectionBar');
-                        buttons[i].appendChild(div);
-                    }
-                }
-
-                tabs.addEventListener('click', function (e) {
-
-                    var current = tabs.querySelector('.is-active');
-                    var link = dom.parentWithClass(e.target, 'pageTabButton');
-
-                    if (link && link != current) {
-
-                        if (current) {
-                            current.classList.remove('is-active');
-                            panels[parseInt(current.getAttribute('data-index'))].classList.remove('is-active');
-                        }
-
-                        link.classList.add('is-active');
-                        animateSelectionBar(link);
-                        var index = parseInt(link.getAttribute('data-index'));
-                        var newPanel = panels[index];
-
-                        tabs.dispatchEvent(new CustomEvent("beforetabchange", {
-                            detail: {
-                                selectedTabIndex: index
-                            }
-                        }));
-
-                        // If toCenter is called syncronously within the click event, it sometimes ends up canceling it
-                        setTimeout(function () {
-
-                            if (animateTabs && animateTabs.indexOf(index) != -1 && /*browserInfo.animate &&*/ newPanel.animate) {
-                                fadeInRight(newPanel);
-                            }
-
-                            tabs.selectedTabIndex = index;
-
-                            tabs.dispatchEvent(new CustomEvent("tabchange", {
-                                detail: {
-                                    selectedTabIndex: index
-                                }
-                            }));
-
-                            newPanel.classList.add('is-active');
-                        }, 120);
-
-                        if (tabs.scroller) {
-                            tabs.scroller.toCenter(link, false);
-                        }
+                ownerpage.addEventListener('viewbeforeshow', function () {
+                    if (tabs.triggerBeforeTabChange && this.firstTabIndex == null) {
+                        tabs.triggerBeforeTabChange();
                     }
                 });
 
-                ownerpage.addEventListener('viewbeforeshow', LibraryBrowser.onTabbedpagebeforeshow);
-
-                var contentScrollSlider = tabs.querySelector('.contentScrollSlider');
-                if (contentScrollSlider) {
-                    tabs.scroller = new scroller(tabs, {
-                        horizontal: 1,
-                        itemNav: 0,
-                        mouseDragging: 1,
-                        touchDragging: 1,
-                        slidee: tabs.querySelector('.contentScrollSlider'),
-                        smart: true,
-                        releaseSwing: true,
-                        scrollBy: 200,
-                        speed: 120,
-                        elasticBounds: 1,
-                        dragHandle: 1,
-                        dynamicHandle: 1,
-                        clickBar: 1,
-                        //centerOffset: window.innerWidth * .05,
-                        hiddenScroll: true,
-                        requireAnimation: true
-                    });
-                    tabs.scroller.init();
-                } else {
-                    tabs.classList.add('hiddenScrollX');
-                }
-            },
-
-            onTabbedpagebeforeshow: function (e) {
-
-                var page = e.target;
-                var delay = 0;
-                var isFirstLoad = false;
-
-                if (!page.getAttribute('data-firstload')) {
-                    delay = 300;
-                    isFirstLoad = true;
-                    page.setAttribute('data-firstload', '1');
-                }
-
-                if (delay) {
-                    setTimeout(function () {
-
-                        LibraryBrowser.onTabbedpagebeforeshowInternal(page, e, isFirstLoad);
-                    }, delay);
-                } else {
-                    LibraryBrowser.onTabbedpagebeforeshowInternal(page, e, isFirstLoad);
-                }
-            },
-
-            onTabbedpagebeforeshowInternal: function (page, e, isFirstLoad) {
-
-                var pageTabsContainer = page.querySelector('.libraryViewNav');
-
-                if (isFirstLoad) {
-
-                    console.log('selected tab is null, checking query string');
-
-                    var selected = page.firstTabIndex != null ? page.firstTabIndex : parseInt(getParameterByName('tab') || '0');
-
-                    console.log('selected tab will be ' + selected);
-
-                    LibraryBrowser.selectedTab(pageTabsContainer, selected);
-
-                } else {
-
-                    // Go back to the first tab
-                    if (!e.detail.isRestored) {
-                        LibraryBrowser.selectedTab(pageTabsContainer, 0);
-                        return;
+                ownerpage.addEventListener('viewshow', function () {
+                    if (this.firstTabIndex) {
+                        tabs.selectedIndex(this.firstTabIndex);
+                        this.firstTabIndex = null;
+                    } else {
+                        tabs.triggerTabChange();
                     }
-                    pageTabsContainer.dispatchEvent(new CustomEvent("beforetabchange", {
-                        detail: {
-                            selectedTabIndex: LibraryBrowser.selectedTab(pageTabsContainer)
+                });
+
+                tabs.addEventListener('beforetabchange', function (e) {
+
+                    if (e.detail.previousIndex != null) {
+                        panels[e.detail.previousIndex].classList.remove('is-active');
+                    }
+
+                    var newPanel = panels[e.detail.selectedTabIndex];
+
+                    if (e.detail.previousIndex != null && e.detail.previousIndex != e.detail.selectedTabIndex) {
+                        if (newPanel.animate && (animateTabs || []).indexOf(e.detail.selectedTabIndex) != -1) {
+                            fadeInRight(newPanel);
                         }
-                    }));
-                    pageTabsContainer.dispatchEvent(new CustomEvent("tabchange", {
-                        detail: {
-                            selectedTabIndex: LibraryBrowser.selectedTab(pageTabsContainer)
-                        }
-                    }));
-                }
+                    }
+
+                    newPanel.classList.add('is-active');
+                });
             },
 
             showTab: function (url, index) {
 
                 var afterNavigate = function () {
 
-                    document.removeEventListener('pagebeforeshow', afterNavigate);
-
+                    document.removeEventListener('pageinit', afterNavigate);
                     if (window.location.href.toLowerCase().indexOf(url.toLowerCase()) != -1) {
-
                         this.firstTabIndex = index;
                     }
                 };
@@ -353,7 +204,7 @@
                     afterNavigate.call(viewManager.currentView());
                 } else {
 
-                    pageClassOn('pagebeforeshow', 'page', afterNavigate);
+                    pageClassOn('pageinit', 'page', afterNavigate);
                     Dashboard.navigate(url);
                 }
             },
@@ -789,7 +640,7 @@
 
                         var radioValue = option.id.replace(',', '_');
                         isChecked = (options.query.SortBy || '').replace(',', '_') == radioValue ? ' checked' : '';
-                        html += '<label class="block"><input type="radio" is="emby-radio" name="SortBy" data-id="' + option.id + '" value="' + radioValue + '" class="menuSortBy" ' + isChecked + ' /><span>' + option.name + '</span></label>';
+                        html += '<label class="radio-label-block"><input type="radio" is="emby-radio" name="SortBy" data-id="' + option.id + '" value="' + radioValue + '" class="menuSortBy" ' + isChecked + ' /><span>' + option.name + '</span></label>';
                     }
                     html += '</div>';
 
@@ -798,9 +649,9 @@
                     html += '</h2>';
                     html += '<div>';
                     isChecked = options.query.SortOrder == 'Ascending' ? ' checked' : '';
-                    html += '<label class="block"><input type="radio" is="emby-radio" name="SortOrder" value="Ascending" class="menuSortOrder" ' + isChecked + ' /><span>' + Globalize.translate('OptionAscending') + '</span></label>';
+                    html += '<label class="radio-label-block"><input type="radio" is="emby-radio" name="SortOrder" value="Ascending" class="menuSortOrder" ' + isChecked + ' /><span>' + Globalize.translate('OptionAscending') + '</span></label>';
                     isChecked = options.query.SortOrder == 'Descending' ? ' checked' : '';
-                    html += '<label class="block"><input type="radio" is="emby-radio" name="SortOrder" value="Descending" class="menuSortOrder" ' + isChecked + ' /><span>' + Globalize.translate('OptionDescending') + '</span></label>';
+                    html += '<label class="radio-label-block"><input type="radio" is="emby-radio" name="SortOrder" value="Descending" class="menuSortOrder" ' + isChecked + ' /><span>' + Globalize.translate('OptionDescending') + '</span></label>';
                     html += '</div>';
                     html += '</div>';
 
@@ -808,7 +659,7 @@
                     document.body.appendChild(dlg);
 
                     // Seeing an issue in Firefox and IE where it's initially visible in the bottom right, then moves to the center
-                    var delay = browserInfo.animate ? 0 : 100;
+                    var delay = browser.animate ? 0 : 100;
                     setTimeout(function () {
                         dialogHelper.open(dlg);
                     }, delay);
