@@ -1,4 +1,4 @@
-﻿define(['jQuery', 'emby-icons'], function ($) {
+﻿define(['jQuery', 'apphost', 'scripts/taskbutton', 'cardStyle'], function ($, appHost, taskButton) {
 
     function changeCollectionType(page, virtualFolder) {
 
@@ -16,7 +16,9 @@
 
             new medialibrarycreator().show({
 
-                collectionTypeOptions: getCollectionTypeOptions(),
+                collectionTypeOptions: getCollectionTypeOptions().filter(function (f) {
+                    return !f.hidden;
+                }),
                 refresh: shouldRefreshLibraryAfterChanges(page)
 
             }).then(function (hasChanges) {
@@ -112,7 +114,7 @@
         menuItems.push({
             name: Globalize.translate('ButtonManageFolders'),
             id: 'edit',
-            ironIcon: 'folder-open'
+            ironIcon: 'folder_open'
         });
 
         menuItems.push({
@@ -124,7 +126,7 @@
         menuItems.push({
             name: Globalize.translate('ButtonRename'),
             id: 'rename',
-            ironIcon: 'mode-edit'
+            ironIcon: 'mode_edit'
         });
 
         require(['actionsheet'], function (actionsheet) {
@@ -180,7 +182,7 @@
 
         virtualFolders.push({
             Name: Globalize.translate('ButtonAddMediaLibrary'),
-            icon: 'add-circle',
+            icon: 'add_circle',
             Locations: [],
             showType: false,
             showLocations: false,
@@ -197,6 +199,8 @@
 
         var divVirtualFolders = page.querySelector('#divVirtualFolders');
         divVirtualFolders.innerHTML = html;
+        divVirtualFolders.classList.add('itemsContainer');
+        divVirtualFolders.classList.add('vertical-wrap');
 
         $('.btnCardMenu', divVirtualFolders).on('click', function () {
             showCardMenu(page, this, virtualFolders);
@@ -243,7 +247,7 @@
             { name: Globalize.translate('FolderTypeTvShows'), value: "tvshows" },
             { name: Globalize.translate('FolderTypeBooks'), value: "books", message: Globalize.translate('MessageBookPluginRequired') },
             { name: Globalize.translate('FolderTypeGames'), value: "games", message: Globalize.translate('MessageGamePluginRequired') },
-            { name: Globalize.translate('FolderTypeHomeVideos'), value: "homevideos" },
+            { name: Globalize.translate('OptionHomeVideos'), value: "homevideos" },
             { name: Globalize.translate('FolderTypeMusicVideos'), value: "musicvideos" },
             { name: Globalize.translate('FolderTypePhotos'), value: "photos" },
             { name: Globalize.translate('FolderTypeUnset'), value: "mixed", message: Globalize.translate('MessageUnsetContentHelp') }
@@ -255,23 +259,23 @@
 
         switch (type) {
             case "movies":
-                return "local-movies";
+                return "local_movies";
             case "music":
-                return "library-music";
+                return "library_music";
             case "photos":
                 return "photo";
             case "livetv":
-                return "live-tv";
+                return "live_tv";
             case "tvshows":
-                return "live-tv";
+                return "live_tv";
             case "games":
                 return "folder";
             case "trailers":
-                return "local-movies";
+                return "local_movies";
             case "homevideos":
-                return "video-library";
+                return "video_library";
             case "musicvideos":
-                return "video-library";
+                return "video_library";
             case "books":
                 return "folder";
             case "channels":
@@ -293,12 +297,12 @@
             style += "min-width:33.3%;";
         }
 
-        html += '<div class="card backdropCard" style="' + style + '" data-index="' + index + '">';
+        html += '<div class="card backdropCard scalableCard" style="' + style + '" data-index="' + index + '">';
 
         html += '<div class="cardBox visualCardBox">';
-        html += '<div class="cardScalable">';
+        html += '<div class="cardScalable visualCardBox-cardScalable">';
 
-        html += '<div class="cardPadder"></div>';
+        html += '<div class="cardPadder cardPadder-backdrop"></div>';
 
         html += '<div class="cardContent">';
         var imgUrl = '';
@@ -310,41 +314,41 @@
         }
 
         if (imgUrl) {
-            html += '<div class="cardImage editLibrary" style="cursor:pointer;background-image:url(\'' + imgUrl + '\');"></div>';
+            html += '<div class="cardImageContainer editLibrary" style="cursor:pointer;background-image:url(\'' + imgUrl + '\');"></div>';
         } else if (!virtualFolder.showNameWithIcon) {
-            html += '<div class="cardImage editLibrary iconCardImage" style="cursor:pointer;">';
-            html += '<iron-icon icon="' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '"></iron-icon>';
+            html += '<div class="cardImageContainer editLibrary" style="cursor:pointer;">';
+            html += '<i class="cardImageIcon md-icon" style="color:#444;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
 
             html += '</div>';
         }
 
+        if (!imgUrl && virtualFolder.showNameWithIcon) {
+            html += '<h1 class="cardImageContainer addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;flex-direction:column;">';
+
+            html += '<i class="cardImageIcon md-icon" style="font-size:300%;color:#888;height:auto;width:auto;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
+
+            if (virtualFolder.showNameWithIcon) {
+                html += '<div style="margin:1em 0;position:width:100%;font-weight:500;color:#444;">';
+                html += virtualFolder.Name;
+                html += "</div>";
+            }
+
+            html += '</h1>';
+        }
+
         // cardContent
         html += "</div>";
 
         // cardScalable
         html += "</div>";
 
-        if (!imgUrl && virtualFolder.showNameWithIcon) {
-            html += '<h1 class="cardImage iconCardImage addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;">';
-
-            html += '<div>';
-            html += '<iron-icon icon="' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '" style="width:45%;height:45%;color:#888;"></iron-icon>';
-
-            if (virtualFolder.showNameWithIcon) {
-                html += '<div style="margin:1.5em 0;position:width:100%;font-weight:500;color:#444;">';
-                html += virtualFolder.Name;
-                html += "</div>";
-            }
-            html += "</div>";
-
-            html += '</h1>';
-        }
-
-        html += '<div class="cardFooter">';
+        html += '<div class="cardFooter visualCardBox-cardFooter">';
 
         if (virtualFolder.showMenu !== false) {
-            html += '<div class="cardText" style="text-align:right; float:right;padding-top:5px;">';
-            html += '<button type="button" is="paper-icon-button-light" class="btnCardMenu"><iron-icon icon="' + AppInfo.moreIcon + '"></iron-icon></button>';
+            var moreIcon = appHost.moreIcon == 'dots-horiz' ? '&#xE5D3;' : '&#xE5D4;';
+
+            html += '<div style="text-align:right; float:right;padding-top:5px;">';
+            html += '<button type="button" is="paper-icon-button-light" class="btnCardMenu autoSize"><i class="md-icon">' + moreIcon + '</i></button>';
             html += "</div>";
         }
 
@@ -404,33 +408,6 @@
         return html;
     }
 
-    pageClassOn('pageinit', "mediaLibraryPage", function () {
-
-        var page = this;
-        $('#selectCollectionType', page).on('change', function () {
-
-            var index = this.selectedIndex;
-            if (index != -1) {
-
-                var name = this.options[index].innerHTML
-                    .replace('*', '')
-                    .replace('&amp;', '&');
-
-                var value = this.value;
-
-                $('#txtValue', page).val(name);
-
-                var folderOption = getCollectionTypeOptions().filter(function (i) {
-
-                    return i.value == value;
-
-                })[0];
-
-                $('.collectionTypeFieldDescription', page).html(folderOption.message || '');
-            }
-        });
-    });
-
     window.WizardLibraryPage = {
 
         next: function () {
@@ -484,10 +461,11 @@
         var page = this;
 
         // on here
-        $('.btnRefresh', page).taskButton({
+        taskButton({
             mode: 'on',
             progressElem: page.querySelector('.refreshProgress'),
-            taskKey: 'RefreshLibrary'
+            taskKey: 'RefreshLibrary',
+            button: page.querySelector('.btnRefresh')
         });
 
     });
@@ -497,8 +475,11 @@
         var page = this;
 
         // off here
-        $('.btnRefresh', page).taskButton({
-            mode: 'off'
+        taskButton({
+            mode: 'off',
+            progressElem: page.querySelector('.refreshProgress'),
+            taskKey: 'RefreshLibrary',
+            button: page.querySelector('.btnRefresh')
         });
 
     });
