@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'cardStyle'], function ($) {
 
     // The base query options
     var query = {
@@ -119,10 +119,22 @@
                 return 0;
             });
 
+            html += '<div class="itemsContainer vertical-wrap">';
             var limit = screen.availWidth >= 1920 ? 15 : 12;
             for (i = 0, length = Math.min(topPlugins.length, limit) ; i < length; i++) {
                 html += getPluginHtml(topPlugins[i], options, installedPlugins);
             }
+            html += '</div>';
+            html += '<br/>';
+            html += '<br/>';
+        }
+
+        var hasOpenTag = false;
+        currentCategory = null;
+
+        if (options.showCategory === false) {
+            html += '<div class="itemsContainer vertical-wrap">';
+            hasOpenTag = true;
         }
 
         for (i = 0, length = availablePlugins.length; i < length; i++) {
@@ -135,12 +147,15 @@
 
                 if (options.showCategory !== false) {
                     if (currentCategory) {
-                        html += '<br/>';
+                        hasOpenTag = false;
+                        html += '</div>';
                         html += '<br/>';
                         html += '<br/>';
                     }
 
                     html += '<div class="detailSectionHeader">' + category + '</div>';
+                    html += '<div class="itemsContainer vertical-wrap">';
+                    hasOpenTag = true;
                 }
 
                 currentCategory = category;
@@ -150,6 +165,10 @@
 
         }
 
+        if (hasOpenTag) {
+            html += '</div>';
+        }
+
         if (!availablePlugins.length && options.noItemsElement) {
             $(options.noItemsElement).hide();
         }
@@ -169,12 +188,12 @@
         }
         var target = plugin.externalUrl ? ' target="_blank"' : '';
 
-        html += "<div class='card backdropCard bottomPaddedCard'>";
+        html += "<div class='card backdropCard scalableCard'>";
 
-        html += '<div class="cardBox visualCardBox">';
-        html += '<div class="cardScalable">';
+        html += '<div class="cardBox cardBox-bottompadded visualCardBox">';
+        html += '<div class="cardScalable visualCardBox-cardScalable">';
 
-        html += '<div class="cardPadder"></div>';
+        html += '<div class="cardPadder cardPadder-backdrop"></div>';
 
         html += '<a class="cardContent" href="' + href + '"' + target + '>';
         if (plugin.thumbImage) {
@@ -198,7 +217,7 @@
         // cardScalable
         html += "</div>";
 
-        html += '<div class="cardFooter">';
+        html += '<div class="cardFooter visualCardBox-cardFooter">';
 
         html += "<div class='cardText'>";
         html += plugin.name;
@@ -208,7 +227,7 @@
             html += "<div class='cardText' style='display:flex;align-items:center;'>";
 
             if (plugin.avgRating) {
-                html += '<iron-icon icon="star" style="color:#666;height:20px;width:20px;min-height:20px;min-width:20px;margin-right:.25em;"></iron-icon>';
+                html += '<i class="md-icon" style="color:#cc3333;margin-right:.25em;">star</i>';
                 html += plugin.avgRating.toFixed(1);
             }
 
